
*------------------------------------------------------------------------------*
* DATA PREPARATION
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------

set more off 
clear all
use "Data/cg_pre_post_conflict_FigureA2.1.dta"


** Generate the neccesary variables
	gen peace_hist = 0
	replace peace_hist = 1 if peace_episode == 1 & acd == 0
	replace peace_hist = 2 if peace_episode >= 2 & acd == 0
	drop if peace_hist == 0



** Collapse the data to know the instances
	tab peace_episode 
	tab peace_hist pts

	gen count = 1 & pts != .

	collapse (sum) count, by(peace_hist pts)

	drop if count == 0


	
** Obtain the total per type of peace
	egen total = sum(count), by(peace_hist)

** Generate the percentages
	gen percentage = 0
	replace percentage = (count*100)/total

	gen min = 0 // to be able to do a rbar

** Allocate them around the PTS value area for plot
	sort pts peace_hist

	
** Generate the x-axis space
	gen x = pts
	replace x = x-0.2 if peace_hist == 1
	replace x = x+0.2 if peace_hist == 2


** Graph
	#delimit ;
	twoway  rbar min percentage x if peace_hist==1, barwidth(.4) col(gs10)
		||  rbar min percentage x if peace_hist==2, barwidth(.4) col(gs0)
			title(,size(medsmall) margin(medsmall) box lc(black) fc(gs14) lw(thin) linegap(2))
			ysize(1) xsize(1)
			xtitle("Physical Integrity Rights Violations (PTS)", height(5))
			ytitle("Percentage", height(5))
			xlabel(1 "1"
				   2 "2"
				   3 "3"
				   4 "4"
				   5 "5",angle(horizontal) nogrid labs(small) ) ymtick(##5)
			xscale(range(1 5))
			yscale(range(0 40))
			ylabel(0(5)40, labs(small) nogrid angle(horizontal))
					legend(order( 1 "Without recent conflict"  
								  2 "Post-conflict")  
						 subtitle("Peace", size(*.6) position(11))
						 bmargin(zero) 
						 col(1) colgap(10) 
						 size(vsmall) symxsize(2) symysize(2)
						 region(lcolor(black) lw(vthin))  
						 ring(0) position(2)) 
			plotregion(lc(black) ls(solid) lw(vthin)) 
			graphregion(margin(small) color(white)) 
			scheme(s2mono)
	;
	# delimit cr

** Save graph
graph export "Figures/cg_peace_postconflict_FigureA2.1.pdf", as(pdf) replace


*-------------------------------------------------------------------------------
* End of do file
*-------------------------------------------------------------------------------
