

*------------------------------------------------------------------------------*
* DATA PREPARATION
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------
clear	all
set		more off


*-------------------
* Opend dataset 
*-------------------
use 	"Data/cg_postconflict_data_with_rebelvictories"


*-------------------
* Sort data
*-------------------
sort	gwno year
tsset	gwno year



* Keep information of interest
	drop if pgm_presence == .
	drop if pgm_warlegacy_count == . & pgm_new_postconf_count == .


* Drop Lebanon
	drop if peace_id == 124 // no PGM information available


* Keep information on the termination type
	tab acd_termination_type
	tab acd_termination_type, nol

	* 1= Rebel victory
	* 2= Government victory
	* 3= Settlement
	* 4= Low intensity


* Collapse first at the peace_episode level
	#delimit;
	collapse (sum) pgm_presence_count
			 (max) acd_termination_type
				   pgm_presence,
			 by(peace_id)
	;
	#delimit cr


* Count how may termination cases 
	gen count = 1


* Collapse by termination type
	#delimit;
	collapse (sum) pgm_presence_count
				   count,
			 by(acd_termination_type pgm_presence)
	;
	#delimit cr


* Count types of termination (within each termiantion type)
	egen total_within = sum(count), by(acd_termination_type)

** Percentages of termiantion with PGMs within termiantion types
	gen percet_within_pgm = (count*100)/total_within if pgm_presence==1

** Generate percentages to compare overall distribution
	egen total_overall =  sum(total_within) if pgm_presence == 1
	gen percet_overall = (total_within*100)/total_overall if pgm_presence==1


** Cases without pgm
	gen no_pgm = total_within - count


** Comparioson between termiantion types
	keep if pgm_presence == 1

* Count types of termination 
	egen total_across = sum(count)

** Cases without PGM total
	egen total_no_pgm = sum(no_pgm)


** Percentages of termiantion with PGMs across termiantion types
	gen percet_with_pgm = (count*100)/total_across 


br


*-------------------------------------------------------------------------------
* End of do file
*-------------------------------------------------------------------------------
