
*------------------------------------------------------------------------------*
* DATA PREPARATION
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------
clear	all
set		more off


*-------------------
* Opend dataset 
*-------------------
use 	"Data/cg_postconflict_data"


*-------------------
* Sort data
*-------------------
sort	gwno year
tsset	gwno year




*-------------------------------------------------------------------------------
* Descriptives
*-------------------------------------------------------------------------------
#delimit ;
local variables="
			pts_alt 
			pgm_warlegacy_count
			pgm_new_postconf_count
			acd_maxduration
			acd_cw
			acd_termination_type
			pko
			xconst
			gov_change_L1
			ptsL1_alt
			media_free_lag
			rgdppc_log
			pop_log
			peace_years 
			peace_years2 
			peace_years3	 	
		"
;
# delimit cr	

sum `variables'

estpost sum `variables'
eststo sumstats


*-------------------------------------------------------------------------------
*- TABLE 
*-------------------------------------------------------------------------------
#delimit ;
esttab sumstats using "Tables/cg_summary_stats.tex", replace 
		cells("count(fmt(0) label(Obs.)) mean(fmt(2) label(Mean)) sd(fmt(2) label(Std. dev.)) min(fmt(2) label(Min.)) max(fmt(2) label(Max.))")
		noobs nomtitle nonumber booktabs 
		coeflabels(
			pts_alt 			    "Physical integrity rights violations"
			pgm_warlegacy_count     "PGM inherited from conflict"
			pgm_new_postconf_count  "PGM new to post-conflict"
			acd_maxduration         "Civil war\$\_{duration}\$"  
			acd_cw 		 		    "Civil war\$\_{intensity}\$"
			acd_termination_type 	"Conflict termination\$\_{type}\$"
			pko              	    "PKO\$\_{presence}\$"
			xconst                  "Executive constraints" 
			gov_change_L1		    "Government change\$\_{lag}\$" 
			ptsL1_alt 	     	    "Physical integrity rights violations\$\_{lag}\$"
			media_free_lag 		    "Free media\$\_{lag}\$"
			pop_log      		    "Population\$\_{log}\$"
			rgdppc_log   		    "GDP\$\_{log}\$"
			peace_years  		    "Peace years" 
			peace_years2 		    "Peace years\$\_{^2}\$" 
			peace_years3 		    "Peace years\$\_{^3}\$"  
			)
		refcat(viol_d "\midrule%" logtroopqual "\midrule%")		
		labcol2(
			"Categorical"
			"Count"
			"Count"
			"Count"
			"Binary"
			"Categorical"
			"Binary"
			"Continuous" 
			"Binary"
			"Categorical"
			"Binary"
			"Continuous"
			"Continuous"
			"Continuous"
			"Continuous"
			"Continuous"
			,title("Type"))
		addnotes("")
		title("Summary")
		substitute(\_ _)
		fragment
		prehead(
		\begin{table}[!ht]\centering
		\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
		\caption{Summary statistics \label{sumstats}}
		\resizebox{14cm}{!}{	
		\begin{tabular}{lc*{1}{ccccc}}
		\toprule
		)
		postfoot(
		\bottomrule
		\multicolumn{7}{l}{\footnotesize }\\
		\end{tabular}
		}
		\end{table}		
		)
		;
#delimit cr


*-------------------------------------------------------------------------------
* End of do file
*-------------------------------------------------------------------------------
