
*------------------------------------------------------------------------------*
* DATA PREPARATION
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------
clear	all
set		more off




*-------------------
* Opend dataset 
*-------------------
use 	"Data/cg_postconflict_data"


*-------------------
* Sort data
*-------------------
sort	gwno year
tsset	gwno year



*------------------------------------------------------------------------------*
* MODELS
*------------------------------------------------------------------------------*


*-------------------------------------------------------------------------------
* Model 1 including PGM ONSET
*-------------------------------------------------------------------------------
version 14

#delimit ;
ologit 	   pts_alt
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   pgm_onset_dummy_L1
		   media_free_lag
		   gov_change_L1
		   pko 
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=5
		   , cl(gwno)
;
#delimit cr
estimates store modelPGMonset
 
*

		   
*-------------------------------------------------------------------------------
* Model 1 including COLD WAR 
*-------------------------------------------------------------------------------

version 14

#delimit ;
ologit 	   pts_alt
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   cold_war // Results: after cold war, more repression
		   media_free_lag
		   gov_change_L1
		   pko 
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=5 
		   , cl(gwno)
;
#delimit cr
estimates store modelCW

*


*-------------------------------------------------------------------------------
* Model 1 including PGM former rebel
*-------------------------------------------------------------------------------

version 14

#delimit ;
ologit 	   pts_alt
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   pgm_former_rebel_dummy
		   media_free_lag
		   gov_change_L1
		   pko 
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=5
		   , cl(gwno)
;
#delimit cr
estimates store modelPGMpriorrebel

*



*-------------------------------------------------------------------------------
* Model 1 including military expenditure
*-------------------------------------------------------------------------------

version 14

#delimit ;
ologit 	   pts_alt
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   milex_log
		   media_free_lag
		   gov_change_L1
		   pko 
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=5
		   , cl(gwno)
;
#delimit cr
estimates store modelMILEXP

*





*------------------------------------------------------------------------------*
* Export results in table 
*------------------------------------------------------------------------------*

#delimit;													
esttab 	modelPGMonset 
		modelCW 
		modelPGMpriorrebel 
		modelMILEXP
using   "Tables/cg_robustness_extra_controls.tex", replace 
b(3) se(3) 
order( 			  pgm_warlegacy_count
				  pgm_new_postconf_count
				  pko
				  xconst
				  gov_change_L1
				  ptsL1_alt
				  media_free_lag
				  rgdppc_log
				  pop_log 
				  pgm_onset_dummy_L1
				  cold_war	
				  pgm_former_rebel_dummy
				  milex_log
				  peace_years 
				  peace_years2 
				  peace_years3
				  _cons
				  ) 
nobaselevels 
stats(chi2 aic N_clust N, star(chi2) fmt(2 2 0 0 0) 
labels("Wald $\chi^{2}$""AIC""Number of clusters""Number of observations")) 
coeflabels( pgm_warlegacy_count    "PGM inherited from conflict\$\_{count}\$"
			pgm_new_postconf_count  "PGM new to post-conflict\$\_{count}\$"
			ptsL1_alt    	        "Physical integrity rights violations\$\_{lag}\$"
			pgm_onset_dummy_L1	    "PGM\$\_{onset, lag}\$" 
			cold_war			    "Cold war\$\_{dummy}\$"
			pgm_former_rebel_dummy  "PGM former rebel\$\_{dummy}\$"
			milex_log				"Military expenditure\$\_{log}\$"
			media_free_lag		    "Free media\$\_{lag}\$"
			acd_termination_d	    "Conflict termination\$\_{dummy}\$"
			gov_change_L1  		    "Government change\$\_{lag}\$"
			pko              	    "PKO\$\_{presence}\$"
			xconst                  "Executive constraints" 
			pop_log      		    "Population\$\_{log}\$"
			rgdppc_log   		    "GDP\$\_{log}\$"
			peace_years  		    "Peace years" 
			peace_years2 		    "Peace years\$\_{^2}\$" 
			peace_years3 		    "Peace years\$\_{^3}\$" 
			cut1:_cons				"Cut 1"
			cut2:_cons				"Cut 2"
			) 
label 
star(\dag 0.10 * 0.05  ** 0.01) 
nonumber
nomtitles 
eqlabels(,none)
nolegend nonotes 
booktabs 
alignment(D{.}{.}{-1}) 
compress
substitute(\_ _)
fragment
prehead(
\begin{table}[!ht]\centering
\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
		\caption{Order logit estimations for the level of human rights violations in post-conflict societies based on Model 1 in Table 2---including control variables for \textit{PGM onset}, the \textit{Cold war}, \textit{PGM former rebels}, \textit{Military expenditure}  \label{tab:models_controls}}
		\setlength{\tabcolsep}{5pt}
		\scalebox{.7}{		
		\begin{tabular}{l*{4}{D{.}{.}{-1}}}
		\hline \hline	
		\addlinespace
		& \multicolumn{4}{c}{\textit{Dependent variable}:}\\ 
		& \multicolumn{4}{c}{Physical Integrity Rights Violations}\\ 
        \addlinespace
		)
		postfoot(
		\hline \hline
		\multicolumn{5}{l}{\footnotesize \textit{Note:} Values are coefficients with robust standard errors in parentheses, }\\
		\multicolumn{5}{l}{\footnotesize   clustered on country. $\dag$ p$<$0.1, * p$<$0.05, ** p$<$0.01. }\\

		\end{tabular}
		}
		\end{table}		
		);
#delimit cr



*------------------------------------------------------------------------------*
* End of do file
*------------------------------------------------------------------------------*
