
*------------------------------------------------------------------------------*
* DATA PREPARATION
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------
clear	all
set		more off




*-------------------
* Opend dataset 
*-------------------
use 	"Data/cg_postconflict_data"


*-------------------
* Sort data
*-------------------
sort	gwno year
tsset	gwno year



*------------------------------------------------------------------------------*
* MODELS
*------------------------------------------------------------------------------*


*------------------------------------------------------------------------------*
* Model A
*------------------------------------------------------------------------------*

*<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>*
*- MODELS with PTS - model 1 from paper estimations
*<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>*

** With regional FE
version 14
#delimit ;
reg 	   pts
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1
		   media_free_lag
		   gov_change_L1
		   pko 
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   americas
		   middleeast
		   asia
		   africa // europe is left out
		   if peace_years<=5, cl(gwno)
;
#delimit cr
estimate store model3ptsCL5yearsFE






*<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>*
*- HETEROGENIETY + AUTOCORRELATION
*<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>*

** With regional FE
#delimit ;
xtpcse 	   pts
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1
		   media_free_lag
		   gov_change_L1
		   pko 
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   americas
		   middleeast
		   asia
		   africa // europe is left out
		   if peace_years<=5 & e(sample)==1
		   , correlation(ar1) p l(90) 
;
#delimit cr
estimate store model3ptsPCSE5yearsFE








*-------------------------------------------------------------------------------
*- MODELS with FARISS data (Model A)
*-------------------------------------------------------------------------------
*
*<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>*
* Standard regression
*<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>*

** With regional FE
#delimit ;
reg 	   fariss_latentmean
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1
		   media_free_lag
		   gov_change_L1
		   pko 
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   americas
		   middleeast
		   asia
		   africa 
		   if peace_years<=5  & e(sample)==1
		   , cluster(gwno)
;
#delimit cr
estimate store model3fCL5yearsFE
*



*<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>*
*- HETEROGENIETY
*<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>*

** With regional FE
#delimit ;
xtpcse 	   fariss_latentmean
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1
		   media_free_lag
		   gov_change_L1
		   pko 
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   americas
		   middleeast
		   asia
		   africa // europe is left out
		   if peace_years<=5  & e(sample)==1
		   , correlation(ar1) p l(90)
;
#delimit cr
estimate store model3fPCSE5yearsFE






*-------------------------------------------------------------------------------
* TABLE with regional FE
*-------------------------------------------------------------------------------
#delimit ;
esttab 	model3fCL5yearsFE     model3fPCSE5yearsFE
		model3ptsCL5yearsFE   model3ptsPCSE5yearsFE
		using "Tables/cg_robustness_old_fe.tex", replace 
		b(3) se(3) 
		stats(r2 rho N_clust N, fmt(2 2 0 0) 
		labels("R$^{2}$" "Rho" "Number of clusters" "Number of observations")
		) 
		order(    pgm_warlegacy_count   
				  pgm_new_postconf_count
				  pko 
				  xconst 	  
				  gov_change_L1
				  ptsL1
				  media_free_lag 
				  rgdppc_log
				  pop_log 	  
				  peace_years 
				  peace_years2 
				  peace_years3
				  _cons
		) 
		coeflabels(
		    ptsL1 		           "Physical integrity rights violations\$\_{lag}\$"
			pgm_warlegacy_count    "PGM inherited from conflict\$\_{count}\$"
			pgm_new_postconf_count "PGM new to post-conflict\$\_{count}\$" 
			media_free_lag      "Media freedom\$\_{lag}\$" 
		    gov_change_L1       "Government change\$\_{lag}\$" 
			pko              	"PKO\$\_{presence}\$"
			xconst        	    "Executive constraints"
			rgdppc_log   	    "GDP\$\_{log}\$"
			pop_log      	 	"Population\$\_{log}\$" 
			peace_years  		"Peace years" 
			peace_years2 		"Peace years\$\_{^2}\$" 
			peace_years3 		"Peace years\$\_{^3}\$" 
			_cons 		 		"Constant"
		)
		indicate(
				"Region FE = americas middleeast asia africa", label("\multicolumn{1}{c@{}}{Yes}")
				)		
		label 
		star(\dag 0.10 * 0.05  ** 0.01) 
		nonumber
		mgroups("\multicolumn{1}{c}{Cluster SE}" "\multicolumn{1}{c}{PCSE}" 
		        "\multicolumn{1}{c}{Cluster SE}" "\multicolumn{1}{c}{PCSE}", pattern(1 1 1 1))
		eqlabels(,none)
		nolegend nonotes 
		booktabs 
		alignment(D{.}{.}{-1}) 
		substitute(\_ _)
		fragment
		prehead(
		\begin{table}[ht]
		\centering
		\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
		\caption{OLS estimations for the level of human rights violations in post-conflict societies based on Model 1 in Table 2---alternative dependent variables including Regional Fixed Effects\label{tab:ols_fe}}
		\setlength{\tabcolsep}{2pt}
		\scalebox{.7}{		
		\begin{tabular}{l*{4}{D{.}{.}{-1}}}
		\hline \hline	
		\addlinespace
		& \multicolumn{2}{c}{\textit{Dependent variable}: Fariss (2014)} & \multicolumn{2}{c}{\textit{Dependent variable}: PTS (1-5)} \\ 
		\cmidrule(r{5pt}l{5pt}){2-3} \cmidrule(r{5pt}l{5pt}){4-5}
		)
		postfoot(
		\hline \hline
		\multicolumn{5}{l}{\footnotesize Values are coefficients with robust standard errors in parentheses, clustered on country.}\\
		\multicolumn{5}{l}{\footnotesize  $\dag$ p$<$0.1, * p$<$0.05, ** p$<$0.01.}\\
		\end{tabular}
		}
		\end{table}		
		);
#delimit cr


	

*------------------------------------------------------------------------------*
* End of do-file
*------------------------------------------------------------------------------*


