
*------------------------------------------------------------------------------*
* MODELS
*------------------------------------------------------------------------------*


*------------------------------------------------------------------------------*
* Model A
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------
clear	all
set		more off

*-------------------
* Opend dataset 
*-------------------
use 	"Data/cg_postconflict_data"


*-------------------
* Sort data
*-------------------
sort	gwno year
tsset	gwno year


version 14
#delimit ;
ologit 	   pts_alt 
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   media_free_lag
		   pko 
		   gov_change_L1
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=5, cl(gwno)
;
#delimit cr

** Correctly predicted cases: Model 1
	
	** Predict each outcome individually
	predict pts_alt2 pts_alt3 pts_alt4 if e(sample)

	** Store prediction values
	gen yhat=.
	replace yhat=2 if pts_alt2>pts_alt3 & pts_alt2>pts_alt4
	replace yhat=3 if pts_alt3>pts_alt2 & pts_alt3>pts_alt4
	replace yhat=4 if pts_alt4>pts_alt2 & pts_alt4>pts_alt3
	
	** Display results assigned to each outcome
	tab pts_alt yhat, col
	
	
	** Isolate correctly predicted cases
	gen correct=yhat
	tab correct
	
	recode correct (2=0) (3=0) (4=0) 
	tab correct
	
	replace correct=1 if pts_alt==2 & yhat==2
	replace correct=1 if pts_alt==3 & yhat==3
	replace correct=1 if pts_alt==4 & yhat==4

	** Display results: overall cases correctly predicted 
	tab correct


	
	
*------------------------------------------------------------------------------*
* Model B
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------
clear	all
set		more off




*-------------------
* Opend dataset 
*-------------------
use 	"Data/cg_postconflict_data"


*-------------------
* Sort data
*-------------------
sort	gwno year
tsset	gwno year



*------------------------------------------------------------------------------*
* MODELS
*------------------------------------------------------------------------------*


version 14
#delimit ;
ologit 	   pts_alt 
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst       
		   ptsL1_alt
		   media_free_lag
		   pko 
		   gov_change_L1
		   rgdppc_log
		   pop_log
		   acd_maxduration
		   acd_cw
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=5, cl(gwno)
;
#delimit cr


** Correctly predicted cases: Model 2
	
	** Predict each outcome individually
	predict pts_alt2 pts_alt3 pts_alt4 if e(sample)

	** Store prediction values
	gen yhat=.
	replace yhat=2 if pts_alt2>pts_alt3 & pts_alt2>pts_alt4
	replace yhat=3 if pts_alt3>pts_alt2 & pts_alt3>pts_alt4
	replace yhat=4 if pts_alt4>pts_alt2 & pts_alt4>pts_alt3
	
	** Display results assigned to each outcome
	tab pts_alt yhat, col
	

	** Isolate correctly predicted cases
	gen correct=yhat
	tab correct
	
	recode correct (2=0) (3=0) (4=0) 
	tab correct
	
	replace correct=1 if pts_alt==2 & yhat==2
	replace correct=1 if pts_alt==3 & yhat==3
	replace correct=1 if pts_alt==4 & yhat==4

	** Display results: overall cases correctly predicted
	tab correct


	

*------------------------------------------------------------------------------*
* Model C
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------
clear	all
set		more off




*-------------------
* Opend dataset 
*-------------------
use 	"Data/cg_postconflict_data"


*-------------------
* Sort data
*-------------------
sort	gwno year
tsset	gwno year



*------------------------------------------------------------------------------*
* MODELS
*------------------------------------------------------------------------------*


tsset gwno year

version 14
#delimit ;
ologit 	   pts_alt 
		   pgm_warlegacy_count 
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   media_free_lag
		   pko 
		   gov_change_L1
		   rgdppc_log
		   pop_log
		   ib4.acd_termination_type
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=5, cl(gwno)
;
#delimit cr



** Correctly predicted cases: Model 3
	
	** Predict each outcome individually
	predict pts_alt2 pts_alt3 pts_alt4 if e(sample)

	** Store prediction values
	gen yhat=.
	replace yhat=2 if pts_alt2>pts_alt3 & pts_alt2>pts_alt4
	replace yhat=3 if pts_alt3>pts_alt2 & pts_alt3>pts_alt4
	replace yhat=4 if pts_alt4>pts_alt2 & pts_alt4>pts_alt3
	
	** Display results assigned to each outcome
	tab pts_alt yhat, col

	
	** Isolate correctly predicted cases
	gen correct=yhat
	tab correct
	
	recode correct (2=0) (3=0) (4=0) 
	tab correct
	
	replace correct=1 if pts_alt==2 & yhat==2
	replace correct=1 if pts_alt==3 & yhat==3
	replace correct=1 if pts_alt==4 & yhat==4

	** Display results: overall cases correctly predicted
	tab correct

	
	** Average of correctly predicted cases: 
	di((66.67 + 67.37 + 67.13)/3)

	
*-------------------------------------------------------------------------------
* End of do file
*-------------------------------------------------------------------------------
